("A modifier" "modificador A")
("GNU" "GNU")
("H modifier" "modificador H")
("LaTeX" "LaTeX")
("M modifier" "modificador M")
("TeX" "TeX")
("abbreviation" "abreviao")
("about" "sobre TeXmacs")
("about menu" "menu sobre")
("above" "acima")
("abstract" "resumo")
("accent" "acento")
("accept" "aceitar")
("accept all scripts" "aceitar todos scripts")
("accept no scripts" "no aceitar scripts")
("accept script" "aceitar script")
("acronym" "acrnimo")
("action" "ao")
("activate" "ativar")
("acute" "agudo")
("address" "endereo")
("address block" "bloco de endereo")
("advanced" "avanado")
("advanced layout features" "Ferramentas de diagramao avanada")
("after" "depois de")
("albanian" "Albans")
("algorithm" "algoritmo")
("align cell to the bottom" "alinhar clula abaixo")
("align cell to the left" "alinhar clula  esquerda")
("align cell to the right" "alinhar clula  direita")
("align cell to the top" "alinhar clula acima")
("align table at base of left column" "alinhar tabela  base da coluna esquerda")
("align table at base of middle column" "alinhar tabela  base da coluna do meio")
("align table at base of origin column" "alinhar tabela  base da coluna de origem")
("align table at base of right column" "alinhar tabela  base da coluna direita")
("align table at fraction bar height" "alinhar tabela  altura do trao de frao")
("align table at the base of bottom row" "alinhar tabela  base da ltima linha")
("align table at the base of middle row" "alinhar tabela  base da linha do meio")
("align table at the base of origin row" "alinhar tabela  base da linha de origem")
("align table at the base of top row" "alinhar tabela  base da primeira linha")
("align table at the bottom" "alinhar tabela abaixo")
("align table at the center" "alinhar tabela ao centro")
("align table at the horizontal center" "alinhar tabela ao centro horizontal")
("align table at the left" "alinhar tabela  esquerda")
("align table at the top" "alinhar tabela acima")
("align table to the right" "alinhar tabela  direita")
("align text to the left" "alinhar texto  esquerda")
("align text to the right" "alinhar texto  direita")
("alignment" "alinhamento")
("all" "tudo")
("allow" "permitir")
("allowed extension" "extenso permitida")
("allowed reduction" "reduo permitida")
("alpha release" "alpha release")
("alt key" "tecla alt")
("and" "e")
("appendix" "apndice")
("apply" "aplicar")
("april" "abril")
("arab" "rabe")
("archaic" "arcaico")
("architecture" "arquitetura")
("argument" "argumento")
("arithmetic" "aritmtica")
("armenian" "armnio")
("arrow" "flecha")
("arrows" "setas")
("article" "artigo")
("as on paper" "como no papel")
("assign" "atribuir")
("at fraction bar height" " altura do trao de frao")
("at the baseline" " linha base")
("at the bottom" "abaixo")
("at the left" " esquerda")
("at the middle" "ao meio")
("at the right" " direita")
("at the top" "ao topo")
("attach" "vincular")
("attach buffer to which project" "vincular buffer ao projeto")
("august" "agosto")
("author" "autor")
("authorize" "autorizar")
("automatic" "automtico")
("automatically generated content" "contedo gerado automaticamente")
("axiom" "axioma")
("background" "fundo")
("background color" "cor de fundo")
("backward replace" "substituir anterior")
("backward search" "procurar anterior")
("bad data format" "formato de dados incorreto")
("bar" "barra")
("bard" "bardo")
("base level" "nvel base")
("bashkirian" "bashkrio")
("basic" "bsico")
("basic data types" "tipos de dados bsicos")
("basic types" "tipos bsicos")
("be useful" "seja til")
("become a TeXmacs developer" "torne-se um desenvolvedor TeXmacs")
("before" "antes de")
("begin" "princpio")
("below" "acima")
("beta release" "beta release")
("bibliography" "bibliografia")
("bibliography file" "arquivo de bibliografia")
("bibliography style" "estilo da bibliografia")
("big" "grande")
("big figure" "figura grande")
("big operator" "operador grande")
("big skip" "salto grande")
("big table" "tabela grande")
("binary operation" "operao binria")
("binary relation" "relao binria")
("black" "negro")
("blackboard bold" "quadro-negro sombreado")
("blackboard math" "quadro-negro matemtico")
("blackletter" "blackletter")
("blue" "azul")
("body" "corpo")
("bold" "grosso")
("book" "livro")
("border" "borda")
("both" "ambos")
("bottom" "baixo")
("bottom border" "borda inferior")
("bottom margin" "margem inferior")
("bottom padding" "borda interna inferior")
("branch" "ramo")
("break" "quebra")
("breaking" "partindo")
("breve" "breve")
("british" "britnico")
("brown" "marrom")
("browse" "navegar")
("browse web" "navegar na rede")
("browser" "navegador")
("buffer" "buffer")
("bulgarian" "blgaro")
("bullet" "marcador")
("bullets" "marcadores")
("by" "por")
("by typing" "escrevendo")
("bytes free" "bytes livres")
("bytes used" "bytes usados")
("calligraphic" "caligrafia")
("cancel" "cancelar")
("caps-lock key" "tecla CAPS-LOCK")
("case" "case")
("cc" "cc")
("cell" "clula")
("cell background color" "cor de fundo da clula")
("cell border" "borda da clula")
("cell height" "altura da clula")
("cell operation mode" "modo de operao da clula")
("cell width" "largura da clula")
("center" "centro")
("center text" "centralizar texto")
("centered" "centralizado")
("centered block" "bloco centralizado")
("centered tabular" "tabular centralizado")
("change border of cell" "mudar borda da clula")
("change cell operation mode" "mudar modo de operao da clula")
("change log" "arquivo de registro de alteraes")
("changes" "mudanas")
("chapter" "captulo")
("check" "check")
("check text for spelling errors" "verificar erros de ortografia")
("chinese" "chins")
("choice" "chave")
("citation" "citao")
("cite" "citar")
("class" "classe")
("clear" "limpar")
("clear selection" "limpar seleo")
("clipped" "grampeado")
("clipped and magnified" "grampeado e ampliado")
("clipped and resized" "grampeado e redimensionado")
("clone" "duplicar")
("clone window" "duplicar janela")
("close" "fechar")
("close TeXmacs" "fechar TeXmacs")
("close buffer" "fechar buffer")
("close session" "encerrar sesso")
("close window" "fechar janela")
("closing" "fechamento")
("code" "cdigo")
("color" "cor")
("column" "coluna")
("column contains glued items" "a coluna contm elementos colados")
("compatibility with other formats" "compatibilidade com outros formatos")
("compile article" "compilar artigo")
("compile book" "compilar livro")
("compile buffer" "compilar buffer")
("compile project" "compilar projeto")
("complex" "complexo")
("concrete" "concrete")
("condensed" "condensado")
("condition" "condio")
("configuration" "configurao")
("content tag" "tag de contedo")
("context dependent icons" "cones dependentes do contexto")
("continuation of" "continuao de")
("convention" "conveno")
("converters to other data formats" "conversores para outros formatos")
("copy" "copiar")
("copy text" "copiar texto")
("copy to" "copiar para")
("copying" "copiando")
("corollary" "corolrio")
("correct text" "corrigir texto")
("cursors" "cursores")
("custom tab" "marca de tabulao customizada")
("customizing TeXmacs" "adaptando o TeXmacs")
("customizing the TeXmacs styles" "adaptando os estilos do TeXmacs")
("cut" "cortar")
("cut text" "cortar texto")
("cut to" "cortar para")
("cypriot" "cipriota")
("cyrillic" "cirlico")
("cyrillic input method" "mtodo de entrada para cirlico")
("cyrillic italic right" "cirlico cursivo direita")
("czech" "tcheco")
("dancers" "bailarinos")
("danish" "dinamarqus")
("dash" "tracesso")
("dashes" "travesses")
("data conversion" "converso de dados")
("data format" "formato de dados")
("date" "data")
("deactivate" "desativar")
("deactivate table" "desativar tabela")
("december" "dezembro")
("decorate atoms" "decorar tomos")
("default" "padro")
("default padding" "borda interna padro")
("definition" "definio")
("delete" "apagar")
("delete column" "apagar coluna")
("delete row" "apagar linha")
("denominator" "denominador")
("description" "descrio")
("destination" "destino")
("detach" "desvincular")
("determinant" "determinante")
("devangari" "devangari")
("developers guide" "guia para desenvolvedores")
("directory" "diretrio")
("disable first indentation" "desabilitar primeira indentao")
("disable first indentation after" "desabilitar primeira identao depois")
("disable first indentation before" "desabilitar primeira indentao antes")
("disable indentation" "desabilitar indentao")
("disable indentation after" "desabilitar indentao depois")
("disable indentation before" "desabilitar indentao antes")
("disable last indentation" "desabilitar ltima indentao")
("disable last indentation after" "desabilitar ltima indentao depois")
("disable last indentation before" "desabilitar ltima indentao antes")
("disallow" "impedir")
("distribute unused space" "distribuir espao vazio")
("div" "div")
("document" "documento")
("document format" "formato de documento")
("document style" "estilo de documento")
("document styles" "estilos de documento")
("documentation" "documentao")
("documents are trees" "documentos so rvores")
("dot" "ponto")
("dots" "pontos")
("double stroke" "trao duplo")
("down" "abaixo")
("dpi" "dpi")
("duplicate" "duplicar")
("dutch" "holands")
("dynamic libraries" "bibliotecas dinmicas")
("edit" "editar")
("editing tools" "ferramentas de edio")
("email" "email")
("emphasize" "destacar")
("emphasize text" "destacar texto")
("empty box" "caixa vazia")
("enable first indentation" "habilitar primeira indentao")
("enable first indentation after" "habilitar primeira indentao depois")
("enable first indentation before" "habilitar primeira indentao antes")
("enable indentation" "habilitar indentao")
("enable indentation after" "habilitar indentao depois")
("enable indentation before" "habilitar indentao antes")
("enable last indentation" "habilitar ltima indentao")
("enable last indentation after" "habilitar ltima indentao depois")
("enable last indentation before" "habilitar ltima indentao antes")
("encl" "incluso")
("end" "fim")
("english" "ingls")
("enter a title" "introduzir um ttulo")
("enumerate" "enumerar")
("enumerate|Alpha" "enumerar|Alpha")
("enumerate|Roman" "enumerar|Romano")
("enumerate|alpha" "enumerar|alpha")
("enumerate|roman" "enumerar|romano")
("env" "env")
("environment" "ambiente")
("epilogue" "eplogo")
("equal" "igual")
("equation" "equao")
("equations" "equaes")
("equivalent for" "equivalente para")
("error" "erro")
("esperanto" "esperanto")
("etruscan" "etrusco")
("evaluate" "avaliar")
("evaluate scheme expression" "avaliar expresso scheme")
("even page footer" "rodap de pginas pares")
("even page header" "cabealho de pginas pares")
("even page margin" "margem da pgina par")
("even page text" "texto de pginas pares")
("exact horizontal" "horizontal exato")
("exact mode" "modo exato")
("exam" "exame")
("example" "exemplo")
("exclusive" "exclusivo")
("exclusive or" "ou exclusivo")
("executable" "executvel")
("execute" "executar")
("execute a TeXmacs command" "executar um comando TeXmacs")
("execute system command" "executar comando do sistema")
("executive" "executivo")
("exercise" "exerccio")
("expand" "expandir")
("explained" "explicado")
("export" "exportar")
("export as" "exportar como")
("extend or normal" "extendido ou normal")
("extern " "externo")
("extra" "extra")
("extract format" "extrair formato")
("family" "famlia")
("february" "fevereiro")
("figure" "figura")
("file" "arquivo")
("file name" "nome do arquivo")
("file not found" "arquivo  no encontrado")
("find next match" "buscar termo coincidente seguinte ")
("find text" "buscar texto")
("finnish" "finlands")
("first contact" "primeiro contato")
("first indentation" "primeira indentao")
("first item" "primeiro elemento")
("first page" "primeira pgina")
("first start" "primeiro comeo")
("flat" "fino")
("flexibility" "flexibilidade")
("flexibility factor for vertical spacing" "fator de flexibilidade para espaamento vertical")
("floating figure" "figura flutuante")
("floating object" "objeto flutuante")
("floating table" "tabela flututante")
("fold" "dobra")
("folded" "dobrado")
("font" "fonte")
("font base size" "tamanho fonte base")
("font dpi" "font dpi")
("font family" "famlia da fonte")
("font name" "nome da fonte")
("font series" "estilo da fonte")
("font shape" "formato da fonte")
("font size" "tamanho da fonte")
("font variant" "variante da fonte")
("fonts" "fontes")
("footer" "rodap")
("footnote" "nota de rodap")
("for" "for")
("foreground" "primeiro plano")
("foreign" "estrangeiro")
("format" "formato")
("formatted date" "data formatada")
("formula" "frmula")
("formula style" "estilo de frmula")
("forward replace" "substituir  frente")
("forward search" "procurar  frente")
("fraction" "frao")
("french" "francs")
("full manuals" "manuais completos")
("function" "funo")
("further customization" "adaptao para o usurio avanado")
("future changes" "mudanas futuras")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs no tem nenhuma forma de garantia legal")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs est sob a licensa pblica GNU (GNU GPL)")
("general architecture of TeXmacs" "arquitetura geral do TeXmacs")
("general negation" "negao geral")
("generating font file" "gerando arquivo de fontes")
("generic" "genrico")
("georgian" "georgiano")
("german" "alemo")
("getting started" "iniciando")
("glossary" "glossrio")
("glossary entry" "item do glossrio")
("glue" "cola")
("glue decorations" "colar decoraes")
("go" "ir para")
("gothic" "gtica")
("graphical interface" "interface grfica")
("grave" "grave")
("greater" "maior")
("greater or equal" "maior ou igual")
("greek" "grego")
("greek letter" "letra grega")
("green" "verde")
("grey" "cinza")
("group" "grupo")
("happy typing" "boa escrita")
("has been aborted" "abortado")
("has completed its task" "finalizou sua tarefa")
("hat" "chapu")
("header" "cabealho")
("header and footer" "cabealho e rodap")
("hebrew" "hebraico")
("height" "altura")
("height is exactly the specified height" "altura  exatamente a altura especificada")
("height is maximum of specified height and box height" "altura  o mximo dentre a altura especificada e altura da caixa")
("height is minimum of specified height and box height" "altura  o mnimo dentre a altura especificada e altura da caixa")
("height magnification" "ampliao da altura")
("help" "ajuda")
("help me" "ajude me")
("help us" "ajude-nos")
("here" "aqui")
("home" "incio")
("horizontal" "horizontal")
("horizontal cell alignment" "alinhamento horizontal da clula")
("horizontal ink separation" "separao de tinta horizontal")
("horizontal part" "parte horizontal")
("horizontal position" "posio horizontal")
("horizontal space" "espao horizontal")
("horizontal table alignment" "alinhamento horizontal da tabela")
("horizontally align cell to the base" "alinhar a clula horizontalmente  base")
("horizontally center the cell" "centralizar horizontalmente a clula")
("how much longer may pages become" "quanto mais longas podem ficar as pginas")
("how much shorter may pages become" "quanto mais curtas podem ficar as pginas")
("huge" "enorme")
("hungarian" "hngaro")
("hyperlink" "hiperlink")
("hyphenation" "hifenao")
("icelandic" "islands")
("if" "if")
("image" "imagem")
("image links" "links para imagens")
("implementation" "implementao")
("import" "importar")
("improving the current implementation" "melhorando a implementao atual")
("inactive" "inativo")
("include" "incluir")
("include a document" "incluir um documento")
("include file" "incluir um arquivo")
("inclusion into TeXmacs" "incluso no TeXmacs")
("inclusions" "incluses")
("indent" "indentar")
("indentation flag" "indentao")
("index" "ndice")
("index entry" "item do ndice")
("index level" "nvel de ndice")
("insert" "inserir")
("insert Pr" "inserir Pr")
("insert a TeXmacs symbol" "inserir um smbolo TeXmacs")
("insert a big operator" "inserir um operador grande")
("insert a binary operation" "inserir uma operao binria")
("insert a binary relation" "inserir uma relao binria")
("insert a calligraphic character" "inserir um caracter caligrfico")
("insert a fraction" "inserir uma frao")
("insert a fraktur character" "inserir um caracter fraktur")
("insert a greek character" "inserir uma letra grega")
("insert a large left delimiter" "inserir um delimitador grande  esquerda")
("insert a large right delimiter" "inserir um delimitador grande  direita")
("insert a large separator" "inserir um separador amplo")
("insert a left subscript" "inserir um subndice  esquerda")
("insert a link" "inserir um link")
("insert a miscellaneous symbol" "inserir um smbolo miscelneo")
("insert a new branch" "inserir um novo ramo")
("insert a new item" "inserir um novo elemento")
("insert a picture" "inserir uma imagem")
("insert a square root" "inserir uma raiz quadrada")
("insert a table" "inserir uma tabela")
("insert a table or a matrix" "inserir uma tabela ou uma matriz")
("insert an" "inserir um/a")
("insert an accent" "inserir um acento")
("insert an arrow" "inserir uma flecha")
("insert an environment" "inserir um novo ambiente")
("insert an n" "inserir um/a n")
("insert appendix" "inserir apndice")
("insert arccos" "inserir arccos")
("insert arcsin" "inserir arcsin")
("insert arctan" "inserir arctan")
("insert arg" "inserir arg")
("insert argument" "inserir argumento")
("insert automatically generated content" "inserir contedo gerado automaticamente")
("insert big contour integral" "inserir integral de contorno grande")
("insert big coproduct" "inserir co-produtrio grande")
("insert big direct sum" "inserir soma direta grande")
("insert big dotted point" "inserir produto pontual grande")
("insert big integral" "inserir integral grande")
("insert big intersection" "inserir interseco grande")
("insert big logical and" "inserir Y lgico grande")
("insert big logical or" "inserir O lgico grande")
("insert big product" "inserir produtrio grande")
("insert big square union" "inserir unio quadrada grande")
("insert big summation" "inserir somatrio grande")
("insert big tensor product" "inserir produto tensorial grande")
("insert big union" "inserir unio grande")
("insert big union sum" "inserir soma unio grande")
("insert big vertical space" "inserir espao vertical grande")
("insert chapter" "inserir captulo")
("insert column" "inserir coluna")
("insert column to the left" "inserir coluna  esquerda")
("insert column to the right" "inserir coluna  direita")
("insert cos" "inserir cos")
("insert cosh" "inserir cosh")
("insert cot" "inserir cot")
("insert coth" "inserir coth")
("insert csc" "inserir csc")
("insert deg" "inserir deg")
("insert det" "inserir det")
("insert dim" "inserir dim")
("insert dollar" "inserir dlar")
("insert equation" "inserir equao")
("insert executable markup" "inserir markup executvel")
("insert exp" "inserir exp")
("insert footnote" "inserir nota de rodap")
("insert formula" "inserir frmula")
("insert gcd" "inserir gcd")
("insert hom" "inserir hom")
("insert horizontal interword space" "inserir espao horizontal entre palavras")
("insert image" "inserir imagem")
("insert inactive markup" "executar markup inativo")
("insert inf" "inserir inf")
("insert ker" "inserir ker")
("insert lg" "inserir lg")
("insert lim" "inserir lim")
("insert liminf" "inserir liminf")
("insert limsup" "inserir limsup")
("insert ln" "inserir ln")
("insert log" "inserir log")
("insert mathematics" "inserir expresso matemtica")
("insert max" "inserir max")
("insert medium horizontal space" "inserir espao horizontal mdio")
("insert medium vertical space" "inserir espao vertical mdio")
("insert min" "inserir min")
("insert negative horizontal space" "inserir espao horizontal negativo")
("insert new item or number" "inserir novo elemento ou nmero")
("insert new rows or columns" "inserir linhas ou colunas")
("insert or delete rows or columns" "inserir ou apagar linhas ou colunas")
("insert row" "inserir linha")
("insert row above" "inserir linha acima")
("insert row below" "inserir linha abaixo")
("insert sec" "inserir sec")
("insert section" "inserir seo")
("insert sharp" "inserir sharp")
("insert sin" "inserir sen")
("insert sinh" "inserir senh")
("insert small horizontal space" "inserir espao horizontal pequeno")
("insert small vertical space" "inserir espao vertical pequeno")
("insert structural markup" "inserir markup estrutural")
("insert subsection" "inserir subseo")
("insert subsubsection" "inserir subsubseo")
("insert sup" "inserir sup")
("insert tan" "inserir tan")
("insert tanh" "inserir tanh")
("insert thick horizontal space" "inserir espao horizontal grosso")
("interjection" "interjeio")
("interline separation" "separao entre linhas")
("interline space" "espao entre linhas")
("internationalization" "internacionalizao")
("interparagraph space" "espao entre pragrafos")
("interrupt execution" "interromper execuo")
("introduction" "introduo")
("invisible" "invisvel")
("invisible citation" "citao invisvel")
("irish" "irlands")
("is running" "est executando")
("is tuple" " tuple")
("ispell does not respond" "ispell no responde")
("ispell is already busy" "ispell est ocupado")
("italian" "italiano")
("italic" "itlico")
("italic right" "itlico direita")
("itemize" "listar")
("january" "janeiro")
("japanese" "japons")
("july" "julho")
("june" "junho")
("justified" "justificado")
("justify text" "justificar texto")
("key" "tecla")
("keyboard" "teclado")
("keyboard equivalent" "equivalente do teclado")
("keyboard modifiers" "modificadores do teclado")
("keyboard shortcut" "atalho do teclado")
("keymaps" "mapa de teclado")
("keyword" "palavra chave")
("keywords" "palavras chaves")
("kill" "matar")
("known bugs" "bugs conhecidos")
("label" "etiqueta")
("landscape" "paisagem")
("language" "linguagem")
("large" "grande")
("large closing bracket" "parntesis fechando grande")
("large delimiter" "delimitador grande")
("large opening bracket" "parntesis abrindo grande")
("large separator" "separador grande")
("last indentation" "ltima indentao")
("last page" "ltima pgina")
("latex command" "comando de latex")
("latin" "latin")
("layout" "layout")
("left" "esquerda")
("left border" "borda esquerda")
("left margin" "margem esquerda")
("left padding" "borda interna esquerda")
("left prime" "prime esquerdo")
("left ragged" "alinhado  esquerda")
("left slanted" "inclinada esquerda")
("left subscript" "subndice  esquerda")
("left superscript" "superndice  esquerda")
("left surrounding" "vizinhana esquerda")
("legal" "legal")
("lemma" "lema")
("length" "length")
("less" "menor")
("less or equal" "menor ou igual")
("letter" "carta")
("license" "licena")
("light" "leve")
("limitations" "limitaes")
("limits" "limites")
("line" "linha")
("line break" "quebra de linha")
("line stretch" "elasticidade da linha")
("link" "link")
("link image" "criar link para imagem")
("list" "lista")
("list of figures" "lista de figuras")
("list of tables" "lista de tabelas")
("load" "carregar")
("load LaTeX file" "carregar arquivo LaTeX")
("load TeX file" "carregar arquivo TeX")
("load TeXmacs file" "carregar arquivo TeXmacs")
("load TeXmacs style file" "carregar arquivo de estilos TeXmacs")
("load a file" "carregar um arquivo")
("load buffer" "carregar buffer")
("load file" "carregar arquivo")
("load html file" "carregar arquivo html")
("load image" "carregar imagem")
("load in new window" "carregar em nova janela")
("load latex file" "carregar arquivo latex")
("load more recent autosave file" "carregar ltimo arquivo gravado")
("load tex file" "carregar arquivo tex")
("load verbatim file" "carregar arquivo verbatim")
("loaded" "carregado")
("long" "alto")
("look and feel" "aparncia")
("look up" "look up")
("lower border" "borda inferior")
("macro" "macro")
("magenta" "magenta")
("magic" "mgico")
("magnification" "ampliao")
("magnified" "ampliado")
("main" "principal")
("main icon bar" "barra de cones principal")
("major changes" "mudanas importantes")
("make a page insertion" "faa uma insero de pgina")
("make a subscript" "criar um subndice")
("make a superscript" "criar um superndice")
("make acute" "fazer agudo")
("make bar" "fazer barra")
("make check" "fazer check")
("make fraction" "fazer frao")
("make grave" "fazer grave")
("make hat" "fazer chapu")
("make label" "criar etiqueta")
("make negation" "fazer negao")
("make page reference" "criar referncia de pgina")
("make reference" "criar referncia")
("make square root" "fazer raiz quadrada")
("make tilde" "fazer til")
("make title" "compor ttulo")
("make vector" "fazer vetor")
("making donations" "fazendo doaes")
("manual" "manual")
("map to" "mapear para")
("march" "maro")
("margins" "margens")
("margins as on paper" "margens como no papel")
("master" "mestre")
("master file" "arquivo mestre")
("math" "math")
("math font" "fonte math")
("math font family" "famlia da fonte math")
("math font series" "estilo da fonte math")
("math font shape" "formato da fonte math")
("mathematical" "matemtico")
("mathematical formulas" "frmulas matemticas")
("mathematical typesetting" "tipografia matemtica")
("mathematics" "matemticos")
("matrix" "matriz")
("maximal number of columns" "nmero mximo de colunas")
("maximal number of rows" "nmero mximo de linhas")
("maximum mode" "modo mximo")
("may" "maio")
("medium" "mdio")
("medium skip" "salto mediano")
("meminfo" "meminfo")
("merge" "merge")
("messy" "confusa")
("meta key" "tecla meta")
("middle" "mdio")
("minimal number of columns" "nmero mnimo de colunas")
("minimal number of rows" "nmero mnimo de linhas")
("minimum mode" "modo mnimo")
("minus" "menos")
("miscellaneous" "miscelneo")
("mod" "mod")
("mode" "modo")
("modifier" "modificador")
("modify cell alignment" "modificar alinhamento da clula")
("modify cell border" "modificar borda da clula")
("modify cell padding" "modificar borda interna da clula")
("modify cell size" "modificar tamanho da clula")
("modify table border" "modificar borda da tabela")
("modify table padding" "modificar borda interna da tabela")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "mais informaes sobre GNU TeXmacs na ajuda")
("mosaic" "mosaico")
("move down" "desloca para baixo")
("move object" "mover objeto")
("move to the right when finished" "move a direita quando finalizado")
("move up" "desloca para cima")
("n-th" "n-sima")
("n-th root" "raiz n-sima")
("name" "nome")
("negation" "negao")
("new" "novo")
("new buffer" "novo buffer")
("new column" "nova coluna")
("new item" "novo elemento")
("new line" "nova linha")
("new number" "novo nmero")
("new page" "nova pgina")
("new page before" "pgina nova antes de")
("new paragraph" "novo pargrafo")
("new roman" "new roman")
("new row" "nova linha")
("new table" "nova tabela")
("next line" "prxima linha")
("no changes need to be saved" "as mudanas no precisam ser gravadas")
("no dictionary for" "sem dicionrio para")
("no first indentation" "sem primeira indentao")
("no indentation" "sem indentao")
("no last indentation" "sem ltima indentao")
("no line break" "sem quebra de linha")
("no matches found" "sem termos coincidentes")
("no more matches for" "no h mais termos coincidentes")
("no more redo information available" "no h mais informao 'refazer' disponvel")
("no more undo information available" "no h mais informao 'desfazer' disponvel")
("no name" "sem nome")
("no page break after" "sem quebra de pgina aps")
("no page break before" "sem quebra de pgina antes")
("no spelling errors found in text" "no foram encontrados erros de ortografia no texto")
("no style" "sem estilo")
("none" "nenhum")
("normal" "normal")
("norwegian" "noruegus")
("not" "no")
("not equal" "no igual")
("not found" "no encontrado")
("notation" "notao")
("note" "nota")
("november" "novembro")
("number" "nmero")
("number equation" "numerar equao")
("number of columns" "nmero de colunas")
("numbered equation" "equao numerada")
("numbered equations" "equaes numeradas")
("numerator" "numerador")
("numeric" "numrico")
("objectives" "objetivos")
("occurrences" "ocorrncias")
("october" "outubro")
("odd page footer" "rodap de pgina impar")
("odd page header" "cabealho de pgina impar")
("odd page margin" "margem da pgina mpar")
("odd page text" "texto de pgina impar")
("off" "desativado")
("ok" "ok")
("old english" "ingls antigo")
("old slavonic" "eslavo antigo")
("old style" "estilo antigo")
("on" "ativado")
("on cells" "nas clulas")
("on columns" "nas colunas")
("on entire table" "na tabela inteira")
("on rows" "nas linhas")
("one spelling error has been corrected" "um erro ortogrfico foi corrigido")
("online documentation" "documentao on-line")
("online help" "ajuda on-line")
("open" "abrir")
("open a new buffer" "abrir um novo buffer")
("open new window" "abrir nova janela")
("opening" "abrindo")
("operation on named selection" "operao na seleo nomeada")
("operation on primary selection" "operao na seleo primria")
("operation on secondary selection" "operao na seleo secundria")
("operation on ternary selection" "operao na seleo ternria")
("optical" "tica")
("option" "opo")
("options" "opes")
("or" "ou")
("orange" "laranja")
("orientation" "orientao")
("origin" "origem")
("original welcome message" "mensagem original de boas-vindas")
("other" "outro")
("other pages" "outras pginas")
("other projects" "outros projetos")
("other style" "outro estilo")
("outlined roman" "perfil romano")
("over" "sobre")
("padding" "borda interna")
("page" "pgina")
("page bottom margin" "margem inferior da pgina")
("page break" "quebra de pgina")
("page break before" "quebra de pgina antes")
("page height" "altura de pgina")
("page insertion" "insero de pgina")
("page layout" "layout de pgina")
("page number text" "texto da numerao de pgina")
("page numbering" "numerao de pgina")
("page reference" "referncia de pgina")
("page right margin" "margem direita da pgina")
("page top margin" "margem superior da pgina")
("page type" "tipo de pgina")
("page width" "largura de pgina")
("paper" "papel")
("paper type" "tipo de papel")
("papyrus" "papiro")
("paragraph" "pargrafo")
("paragraph mode" "modo do paragrfo")
("paragraph width" "largura do pargrafo")
("part" "parte")
("past changes" "mudanas passadas")
("paste" "colar")
("paste from" "colar de")
("paste text" "colar texto")
("path" "caminho")
("perform operations on cells" "realizar operaes nas clulas")
("perform operations on columns" "realizar operaes nas colunas")
("perform operations on entire table" "realizar operaes na tabela inteira")
("perform operations on rows" "realizar operaes nas linhas")
("permanent" "permanente")
("person" "pessoa")
("personal dictionary has been modified" "dicionrio pessoal foi modificado")
("phantasy" "fantasia")
("philosophy" "filosofia")
("phoenician" "fencio")
("phonetic" "fontico")
("pink" "rosa")
("plain block" "bloco simples")
("plain tabular" "tabular simples")
("planned changes" "mudanas planejadas")
("plans for the future" "planos para o futuro")
("please" "por favor")
("please wait" "por favor aguarde")
("plus" "mais")
("polish" "polons")
("porting TeXmacs to other platforms" "tranportando o TeXmacs para outras plataformas")
("portrait" "retrato")
("portuguese" "portugus")
("position" "posio")
("position float" "posicionar flutuatante")
("position floating object" "posicionar objeto flutuante")
("position the table" "posicionar a tabela")
("postscript" "postscript")
("postscript image" "imagem postscript")
("pre-alpha release" "pre-alpha release")
("preamble" "prembulo")
("preamble mode" "modo de prembulo")
("preferences" "preferncias")
("presentation mode" "modo de apresentao")
("preview before printing" "visualizar antes de imprimir")
("preview with ghostview" "visualizar com ghostview")
("primary" "primrio")
("prime" "prime")
("print" "imprimir")
("print all" "imprimir tudo")
("print all to file" "imprimir tudo em um arquivo")
("print page selection" "imprimir seleo")
("print page selection to file" "imprimir seleo em um arquivo")
("print to postscript file" "imprimir em arquivo postscript")
("printer" "impressora")
("printer dpi" "dpi da impressora")
("printing command" "comando de impresso")
("problem" "problema")
("professional" "profissional")
("prog" "prog")
("prog font" "fonte prog")
("prog font family" "familia da fonte prog")
("prog font series" "estilo da fonte prog")
("prog font shape" "forma da fonte prog")
("program" "programa")
("program mode" "modo programa")
("programming" "programao")
("progressive" "progressivo")
("project" "projeto")
("projects" "projetos")
("prologue" "prlogo")
("prompt on scripts" "perguntar em todos os scripts")
("proof" "demostrao")
("proportional" "proporcional")
("proportional typewriter" "typewriter proporcional")
("proposition" "proposio")
("query replace" "substituir")
("quit" "sair")
("quotation" "citao")
("quote" "citar")
("range" "range")
("really close it" "fechar realmente")
("really huge" "gigante")
("really quit" "sair de verdade")
("red" "vermelho")
("redo" "refazer")
("redo undone changes" "refazer as ltimas alteraes")
("reduce bottom margin by" "reduzir margem inferior por")
("reduce left margin by" "reduzir margem esquerda por")
("reduce margins" "reduzir margens")
("reduce right margin by" "reduzir margem direita por")
("reduce top margin by" "reduzir margem superior por")
("reduction even page margin" "reduo da margem da pgina par")
("reduction odd page margin" "reduo da margem da pgina mpar")
("reduction page bottom margin" "reduo da margem inferior da pgina")
("reduction page right margin" "reduo da margem direita da pgina")
("reduction page top margin" "reduo da margem superior da pgina")
("reference" "referncia")
("references" "referncias")
("regular" "regular")
("release" "release")
("reload" "recarregar")
("remark" "comentrio")
("remove number" "remover nmerao")
("renumber this page" "renumerar esta pgina")
("repeat object" "repetir objeto")
("replace" "substituir")
("replace by" "substituir por")
("replaced" "substitudo")
("replaced one occurrence" "substituda uma ocorrncia")
("reset" "reiniciar")
("resize object" "redimensionar objeto")
("resized" "redimensionado")
("return" "return")
("revert" "reverter para")
("revert buffer" "recuperar buffer")
("right" "direita")
("right border" "borda direita")
("right margin" "margem direita")
("right padding" "borda interna direita")
("right ragged" "alinhado  direita")
("right subscript" "subndice  direita")
("right superscript" "superndice  direita")
("right surrounding" "vizinhana direita")
("rigid" "rgido")
("rigid horizontal" "horizontal rgida")
("rigid space" "espao rgido")
("romanian" "romano")
("root" "raiz")
("rotate backward" "rodar para trs")
("rotate forward" "rodar para a frente")
("row" "linha")
("row contains glued items" "a linha contm elementos colados")
("runic" "rnico")
("russian" "russo")
("russian and Ukrainian users" "usurios russos e ucranianos")
("sample" "amostra")
("sans serif" "sans serif")
("save" "salvar")
("save TeXmacs file" "salvar arquivo TeXmacs")
("save TeXmacs style file" "salvar arquivo de estilos TeXmacs")
("save as" "salvar como")
("save as LaTeX" "salvar como LaTeX")
("save as TeX" "salvar como TeX")
("save buffer" "salvar buffer")
("save buffer as" "salvar buffer como")
("save file" "salvar arquivo")
("save html file" "salvar arquivo html")
("save image" "salvar imagem")
("save latex file" "salvar arquivo latex")
("save tex file" "salvar arquivo tex")
("save this buffer" "salvar este buffer")
("save verbatim file" "salvar arquivo verbatim")
("saved" "salvar")
("screen layout" "layout da tela")
("screen margins" "margens na tela")
("script" "ndice")
("script above" "ndice acima")
("script below" "ndice abaixo")
("script script size" "tamanho de script de script")
("script size" "tamanho de script")
("scripts not accepted" "scripts no aceitos")
("search" "procurar")
("searching" "procurando")
("secondary" "secundrio")
("section" "seo")
("security" "segurana")
("see" "ver")
("select a document style" "selecionar um estilo de documento")
("select a foreground color" "selecionar uma cor de primeiro plano")
("select a language" "selecionar uma linguagem")
("selected region" "regio selecionada")
("selection" "seleo")
("selections" "selees")
("seminar" "seminrio")
("separation between lines" "separao entre linhas")
("separation between paragraphs" "separao entre pargrafos")
("separator" "separador")
("september" "setembro")
("serb" "srvio")
("series" "estilo")
("series|right" "estilo|direita")
("session" "sesso")
("session name" "nome da sesso")
("session type" "tipo de sesso")
("sessions" "sesses")
("set" "configurar")
("set background color of cell" "definir cor de fundo da clula")
("set cell mode" "definir modo de clula")
("set extension center" "definir centro da expanso")
("set height" "definir altura")
("set height of cell" "definir altura da clula")
("set margins" "configurar margens")
("set n" "configura n")
("set paragraph margins" "definir margens de pargrafo")
("set paragraph mode" "definir modo de pargrafo")
("set printer dpi" "configurar dpi da impressora")
("set printing command" "configurar arquivo de impresso")
("set span" "definir extenso")
("set special cell properties" "definir propriedades especiais de clula")
("set special table properties" "definir propriedades especiais de tabela")
("set text width" "configurar largura do texto")
("set width" "definir largura")
("set width of cell" "definir largura da clula")
("settings" "ajustes")
("setup printer" "configurar impressora")
("shape" "forma")
("shift-down" "shift-abaixo")
("shift-right" "shift-direita")
("show" "mostrar")
("show header and footer" "mostrar cabealho e rodap")
("show on screen" "mostrar na tela")
("shrinking factor" "fator de reduo")
("signature" "assinatura")
("size" "tamanho")
("size limits" "limites de tamanho")
("slanted" "inclinado")
("small" "pequeno")
("small caps" "caixa alta")
("small figure" "figura pequena")
("small skip" "salto pequeno")
("small table" "tabela pequena")
("source code" "cdigo fonte")
("space" "espao")
("space between lines" "espao entre as linhas")
("space between paragraphs" "espao entre os pargrafos")
("spacing" "espaado")
("spanish" "espanhol")
("special" "especial")
("special cell properties" "propriedades especiais de clula")
("special table properties" "propriedades especiais de tabela")
("specific" "especfico")
("spell" "ortografia")
("spell checking complete" "verificao de ortografia finalizada")
("spelling error" "error ortogrfico")
("spelling errors have been corrected" "os erros ortogrficos foram corrigidos")
("split" "dividir")
("square root" "raiz quadrada")
("start" "inicia")
("start a new chapter" "iniciar um novo captulo")
("start a new section" "iniciar uma nova seo")
("start an interactive session" "iniciar uma sesso interativa")
("stretchable" "esticvel")
("stretchable horizontal" "esticvel horizontal")
("stretchable vertical" "esticvel vertical")
("strong" "forte")
("structural" "estrutural")
("style" "estilo")
("styles" "estilos")
("sub" "sub")
("subparagraph" "subpargrafo")
("subscript" "subndice")
("subsection" "subseo")
("subsub" "subsub")
("subsubsection" "subsubseo")
("summary" "resumo")
("superpose" "superpor")
("superposed" "superpostos")
("superscript" "superndice")
("swedish" "sueco")
("switch to first" "mudar para o primeiro")
("switch to formula style" "mudar o estilo de frmula")
("switch to last" "mudar para o ltimo")
("switch to next" "mudar para o prximo")
("switch to previous" "mudar para o anterior")
("symbol" "smbolo")
("system environment variables" "variveis de sistema do ambiente")
("tab" "tabulador")
("table" "tabela")
("table command" "comando de tabela")
("table of contents" "tabela de contedos")
("tables" "tabelas")
("tabular" "tabular")
("tabular material" "material tabular")
("teXmacs as an interface" "teXmacs como uma interface")
("teXmacs fonts" "fontes do teXmacs")
("teXmacs notice" "aviso do teXmacs")
("teXmacs style files" "arquivos de estilo do teXmacs")
("ternary" "ternrio")
("test" "testar")
("tex" "tex")
("text" "texto")
("text font" "fonte texto")
("text height correction" "correo da altura do texto")
("text width" "largura do texto")
("texts" "textos")
("th century bc" "-ava centuria ac")
("th root" "sima raiz")
("thai" "tailands")
("the TeXmacs authors" "os autores do TeXmacs")
("the application did not send its usual startup banner" "a aplicao no enviou seu aviso de incio habitual")
("the application does not reply" "a aplicao no responde")
("the application is already running" "a aplicao j est sendo executada")
("the boxes produced by the typesetter" "as caixas produzidas pelo tipgrafo")
("the graphical user interface" "a interface grfica")
("the leaves of TeXmacs trees" "as folhas da rvore do TeXmacs")
("the mycas example" "o exemplo mycas")
("the primitive TeXmacs constructs" "as primitivas do TeXmacs")
("the standard TeXmacs styles" "os estilos padro do TeXmacs")
("theorem" "teorema")
("there are unsaved files" "h arquivos no gravados")
("this buffer has not been saved" "este buffer no foi salvo")
("this document has been produced using" "este documento foi produzido usando")
("this line" "esta linha")
("this page" "esta pgina")
("tilda" "tilda")
("tilde" "til")
("times" "vezes")
("tiny" "pequeno")
("title" "ttulo")
("to the left" " esquerda")
("to the right" " direita")
("today" "hoje")
("tools" "ferramentas")
("top" "alto")
("top border" "borda superior")
("top level" "nvel superior")
("top margin" "margem superior")
("top padding" "borda interna superior")
("translate" "traduzir")
("tree" "rvore")
("tuple" "tuple")
("turkish" "turco")
("tutorial" "tutorial")
("type" "tipo")
("type a latex command followed by" "escreva um comando de latex seguido por")
("type body" "escreva o corpo")
("type denominator" "escreva o denominador")
("type numerator" "escreva o numerador")
("type script" "escreva o ndice")
("typesetted boxes" "caixas tipogrficas")
("typewriter" "typewriter")
("typewriter small caps" "typewriter minsculo")
("typing a simple text" "digitando um texto simples")
("typing simple texts" "digitando textos simples")
("ugaritic" "ugartico")
("ukrainian" "ucraniano")
("undo" "desfazer")
("undo last changes" "desfazer as ltimas alteraes")
("up" "acima")
("update" "atualizar")
("update image links" "atualizar links de imagens")
("upper border" "borda superior")
("use a black color" "usar cor negra")
("use a blue color" "usar cor azul")
("use a brown color" "usar cor marrom")
("use a calligraphic font" "usar uma fonte caligrfica")
("use a green color" "usar cor verde")
("use a grey color" "usar cor cinza")
("use a magenta color" "usar cor magenta")
("use a orange color" "usar cor laranja")
("use a pink color" "usar cor rosa")
("use a red color" "usar cor vermelha")
("use a sans serif font" "usar uma fonte sans serif")
("use a typewriter font" "usar uma fonte typewriter")
("use a white color" "usar cor branca")
("use a yellow color" "usar cor amarela")
("use blackboard bold font" "usar fonte quadro-negro negrito")
("use bold font series" "usar estilo de fonte negrito")
("use calligraphical font" "usar fonte de caligrafia")
("use footnote font size" "usar tamanho de fonte rodap")
("use fraktur font" "usar fonte fraktur")
("use huge font size" "usar tamanho de fonte enorme")
("use italic font shape" "usar forma de fonte cursiva")
("use large font size" "usar tamanho de fonte grande")
("use left hand column as border" "usar coluna da esquerda como borda")
("use medium font series" "usar estilo de fonte mdio")
("use normal font size" "usar tamanho de fonte normal")
("use package" "usar pacote")
("use paragraph width" "usar largura de pargrafo")
("use really huge font size" "usar tamanho de fonte gigante")
("use right font shape" "usar forma de fonte reta")
("use right hand column as border" "usar coluna da direita como borda")
("use roman font family" "usar famlia de fonte romana")
("use row above as border" "usar linha acima como borda")
("use row below as border" "usar linha abaixo como borda")
("use sans serif font family" "usar famlia de fonte sans serif")
("use script font size" "usar tamanho de fonte ndice")
("use slanted font shape" "usar forma de fonte inclinada")
("use small capitals" "usar minsculas")
("use small font size" "usar tamanho de fonte pequeno")
("use small-caps font shape" "usar forma de fonte minsculas")
("use the blackboard bold font" "usar fonte quadro-negro negrito")
("use the fraktur font" "usar uma fonte fraktur")
("use tiny font font size" "usar tamanho de fonte diminuta")
("use typewriter font family" "usar famlia de fonte typewriter")
("use very large font size" "usar tamanho de fonte muito grande")
("user manual" "manual do usurio")
("user provided icons" "cones proporcionados pelo usurio")
("value" "valor")
("variable" "varivel")
("variant" "varianta")
("vector" "vetor")
("verbatim" "verbatim")
("verse" "verso")
("vertical" "vertical")
("vertical after" "vertical posterior")
("vertical before" "vertical anterior")
("vertical cell alignment" "alinhamento vertical da clula")
("vertical part" "parte vertical")
("vertical position" "posio vertical")
("vertical space" "espao vertical")
("vertical table alignment" "alinhamento vertical da tabela")
("vertically align cell to the base" "alinhar clula verticalmente  base")
("vertically center the cell" "centralizar verticamente a clula")
("very large" "muito grande")
("very small" "muito pequeno")
("vietnamese" "vietnamita")
("view" "ver")
("visible" "visvel")
("warning" "aviso")
("welcome" "bem vindo")
("welcome to GNU TeXmacs" "bem vindo ao GNU TeXmacs")
("what is new" "quais as novidades")
("when finished" "quando finalizado")
("while" "while")
("white" "branco")
("wide accent" "acento ancho")
("width" "largura")
("width is exactly the specified width" "largura  exatamente a largura especificada")
("width is maximum of specified width and box width" "largura  o mximo dentre largura especificada e largura da caixa")
("width is minimum of specified width and box width" "largura  o mximo dentre largura especificada e largura da caixa")
("width magnification" "ampliao da largura")
("window" "janela")
("window height" "altura da janela")
("window width" "largura da janela")
("windows key" "tecla windows")
("with" "com")
("write a name" "escrever nome")
("write bold mathematics" "escrever termo matemtico em negrito")
("write bold text" "escrever em negrito")
("write italic text" "escrever em itlico")
("write sample text" "escrever texto estilo sample")
("write strong text" "escrever texto estilo forte")
("write typewriter text" "escrever estilo mquina")
("write verbatim text" "escrever texto estilo verbatim")
("writing data converters" "escrevendo conversores de dados")
("writing your own style files" "escrevendo seus prprios arquivos de estilo")
("yellow" "amarelo")
("you can also obtain" "voc tambm pode obter")
("your document is back in its original state" "seu documento foi colocado no estado original")
("your first interface" "sua primeira interface")
